@@ -18,25 +18,29 @@ function (x, y, ...)
     CovarianceDuBruitDeLa <- list()
     MoyenneDeLa <- list()
     detCov <- list()
-    for (cle in 1:2) {
+    for (cle in sort(unique(as.numeric(y)))) {
         CovarianceDuBruitDeLa[[cle]] <- matrix(ncol = dim(X_)[2], 
             nrow = dim(X_)[2], data = 0)
         MoyenneDeLa[[cle]] <- matrix(ncol = dim(X_)[2], nrow = 2, 
             data = 0)
+        if (length(which(Y_ == (cle-1))) <= 1) {
+            stop("the number of data linked to a label has to be strictly greater than 1")
+            return(-1)
+        }
         CovarianceDuBruitDeLa[[cle]] = cov(as.matrix(X_[which(Y_ == 
-            (cle - 1)), ], ncol = dim(X_)[2]))
+            (cle-1)), ], ncol = dim(X_)[2]))
         if (det(CovarianceDuBruitDeLa[[cle]]) == 0) {
             CovarianceDuBruitDeLa[[cle]] = matrix(cov.shrink(as.matrix(X_[which(Y_ == 
-                (cle - 1)), ], ncol = dim(X_)[2]), verbose = FALSE), 
+                (cle-1)), ], ncol = dim(X_)[2]), verbose = FALSE), 
                 ncol=dim(X_)[2])
         }
-		
-		if (det(CovarianceDuBruitDeLa[[cle]]) == 0) {
-			stop("the determinant of the covariance is zero")
-		}
-		
-        MoyenneDeLa[[cle]] = apply(as.matrix(X_[which(Y_ == (cle - 
-            1)), ], ncol = dim(X_)[2]), MARGIN = 2, FUN = mean)
+	
+	if (det(CovarianceDuBruitDeLa[[cle]]) == 0) {
+		stop("the determinant of the covariance is zero")
+	}
+
+        MoyenneDeLa[[cle]] = apply(matrix(X_[which(Y_ == (cle-1)), ], ncol = dim(X_)[2], 
+            nrow=length(which(Y_ == (cle-1)))),MARGIN = 2, FUN = mean)
         detCov[[cle]] = det(CovarianceDuBruitDeLa[[cle]])
     }
     res = list(mean = MoyenneDeLa, cov = CovarianceDuBruitDeLa, 
