@@ -7,4 +7,9 @@ verify.ho <-
 function (model, filter, Xlearn, Ylearn, Xval, Yval, nbreVarX, ...) 
 {
     UseMethod("verify.ho")
+}
+verify.cv <-
+function (model, filter, X,Y, nbreVarX,k, ...) 
+{
+    UseMethod("verify.cv")
 }
\ No newline at end of file
